=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2006-02-28 04:35:06 +0000
+++ bzrlib/builtins.py	2006-02-28 15:10:14 +0000
@@ -31,7 +31,8 @@
 import bzrlib.errors as errors
 from bzrlib.errors import (BzrError, BzrCheckError, BzrCommandError, 
                            NotBranchError, DivergedBranches, NotConflicted,
-                           NoSuchFile, NoWorkingTree, FileInWrongBranch)
+                           NoSuchFile, NoWorkingTree, FileInWrongBranch,
+                           NotVersionedError)
 from bzrlib.log import show_one_log
 from bzrlib.merge import Merge3Merger
 from bzrlib.option import Option
@@ -1798,6 +1799,8 @@
                 interesting_ids = set()
                 for filename in file_list:
                     file_id = tree.path2id(filename)
+                    if file_id is None:
+                        raise NotVersionedError(filename)
                     interesting_ids.add(file_id)
                     if tree.kind(file_id) != "directory":
                         continue

=== modified file 'bzrlib/merge.py'
--- bzrlib/merge.py	2006-02-23 15:12:47 +0000
+++ bzrlib/merge.py	2006-02-27 20:48:40 +0000
@@ -227,7 +227,8 @@
 
     def do_merge(self):
         kwargs = {'working_tree':self.this_tree, 'this_tree': self.this_tree, 
-                  'other_tree': self.other_tree}
+                  'other_tree': self.other_tree, 
+                  'interesting_ids': self.interesting_ids}
         if self.merge_type.requires_base:
             kwargs['base_tree'] = self.base_tree
         if self.merge_type.supports_reprocess:
@@ -318,7 +319,8 @@
     history_based = False
 
     def __init__(self, working_tree, this_tree, base_tree, other_tree, 
-                 reprocess=False, show_base=False, pb=DummyProgress()):
+                 interesting_ids=None, reprocess=False, show_base=False,
+                 pb=DummyProgress()):
         """Initialize the merger object and perform the merge."""
         object.__init__(self)
         self.this_tree = working_tree
@@ -330,8 +332,11 @@
         self.show_base = show_base
         self.pb = pb
 
-        all_ids = set(base_tree)
-        all_ids.update(other_tree)
+        if interesting_ids is not None:
+            all_ids = interesting_ids
+        else:
+            all_ids = set(base_tree)
+            all_ids.update(other_tree)
         self.tt = TreeTransform(working_tree, self.pb)
         try:
             for num, file_id in enumerate(all_ids):
@@ -708,11 +713,13 @@
     supports_show_base = False
 
     def __init__(self, working_tree, this_tree, base_tree, other_tree, 
-                 pb=DummyProgress()):
+                 interesting_ids=None, pb=DummyProgress()):
         self.this_revision_tree = self._get_revision_tree(this_tree)
         self.other_revision_tree = self._get_revision_tree(other_tree)
         super(WeaveMerger, self).__init__(working_tree, this_tree, 
-                                          base_tree, other_tree, pb=pb)
+                                          base_tree, other_tree, 
+                                          interesting_ids=interesting_ids, 
+                                          pb=pb)
 
     def _get_revision_tree(self, tree):
         """Return a revision tree releated to this tree.

=== modified file 'bzrlib/tests/blackbox/test_too_much.py'
--- bzrlib/tests/blackbox/test_too_much.py	2006-02-22 23:02:29 +0000
+++ bzrlib/tests/blackbox/test_too_much.py	2006-02-27 20:48:40 +0000
@@ -725,8 +725,11 @@
         assert '|||||||' not in conflict_text
         assert 'hi world' not in conflict_text
         os.unlink('hello.OTHER')
+        os.unlink('question.OTHER')
+        self.runbzr('remerge jello --merge-type weave', retcode=3)
         self.runbzr('remerge hello --merge-type weave', retcode=1)
         assert os.path.exists('hello.OTHER')
+        self.assertIs(False, os.path.exists('question.OTHER'))
         file_id = self.runbzr('file-id hello')
         file_id = self.runbzr('file-id hello.THIS', retcode=3)
         self.runbzr('remerge --merge-type weave', retcode=1)

=== modified file 'bzrlib/tests/test_merge_core.py'
--- bzrlib/tests/test_merge_core.py	2006-02-21 15:23:00 +0000
+++ bzrlib/tests/test_merge_core.py	2006-02-27 20:48:40 +0000
@@ -43,7 +43,7 @@
         for tt in (self.this_tt, self.base_tt, self.other_tt):
             new_file(tt)
 
-    def merge(self, merge_type=Merge3Merger):
+    def merge(self, merge_type=Merge3Merger, interesting_ids=None):
         self.base_tt.apply()
         self.base.commit('base commit')
         for tt, wt in ((self.this_tt, self.this), (self.other_tt, self.other)):
@@ -53,7 +53,8 @@
             assert len(wt.branch.revision_history()) == 2
         self.this.branch.fetch(self.other.branch)
         other_basis = self.other.branch.basis_tree()
-        merger = merge_type(self.this, self.this, self.base, other_basis)
+        merger = merge_type(self.this, self.this, self.base, other_basis, 
+                            interesting_ids=interesting_ids)
         return merger.cooked_conflicts
 
     def list_transforms(self):
@@ -192,6 +193,16 @@
         conflicts = builder.merge()
         self.assertEqual(conflicts, [('path conflict', '1', 'name3', 'name2')])
         builder.cleanup()
+
+    def test_merge_one(self):
+        builder = MergeBuilder()
+        builder.add_file("1", "TREE_ROOT", "name1", "hello1", True)
+        builder.change_contents("1", other="text4")
+        builder.add_file("2", "TREE_ROOT", "name2", "hello1", True)
+        builder.change_contents("2", other="text4")
+        builder.merge(interesting_ids=["1"])
+        self.assertEqual(builder.this.get_file("1").read(), "text4" )
+        self.assertEqual(builder.this.get_file("2").read(), "hello1" )
         
     def test_file_moves(self):
         """Test moves"""

